@@ -79,6 +79,7 @@ class ReportType(str, Enum):
     GET_FBA_RECOMMENDED_REMOVAL_DATA = 'GET_FBA_RECOMMENDED_REMOVAL_DATA'
     GET_FBA_FULFILLMENT_REMOVAL_ORDER_DETAIL_DATA = 'GET_FBA_FULFILLMENT_REMOVAL_ORDER_DETAIL_DATA'
     GET_FBA_FULFILLMENT_REMOVAL_SHIPMENT_DETAIL_DATA = 'GET_FBA_FULFILLMENT_REMOVAL_SHIPMENT_DETAIL_DATA'
+    GET_FBA_INVENTORY_PLANNING_DATA = 'GET_FBA_INVENTORY_PLANNING_DATA'
     GET_FBA_UNO_INVENTORY_DATA = 'GET_FBA_UNO_INVENTORY_DATA'
     GET_FLAT_FILE_SALES_TAX_DATA = 'GET_FLAT_FILE_SALES_TAX_DATA'
     SC_VAT_TAX_REPORT = 'SC_VAT_TAX_REPORT'
@@ -93,8 +94,12 @@ class ReportType(str, Enum):
     FEE_DISCOUNTS_REPORT = 'FEE_DISCOUNTS_REPORT'
     GET_FLAT_FILE_OFFAMAZONPAYMENTS_SANDBOX_SETTLEMENT_DATA = 'GET_FLAT_FILE_OFFAMAZONPAYMENTS_SANDBOX_SETTLEMENT_DATA'
     GET_BRAND_ANALYTICS_SEARCH_TERMS_REPORT = 'GET_BRAND_ANALYTICS_SEARCH_TERMS_REPORT'
+    GET_VENDOR_FORECASTING_REPORT = 'GET_VENDOR_FORECASTING_REPORT'
     GET_VENDOR_SALES_DIAGNOSTIC_REPORT = 'GET_VENDOR_SALES_DIAGNOSTIC_REPORT'
+    GET_VENDOR_SALES_REPORT = 'GET_VENDOR_SALES_REPORT'
+    GET_VENDOR_TRAFFIC_REPORT = 'GET_VENDOR_TRAFFIC_REPORT'
     GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT = 'GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT'
+    GET_VENDOR_INVENTORY_REPORT = 'GET_VENDOR_INVENTORY_REPORT'
     GET_VENDOR_DEMAND_FORECAST_REPORT = 'GET_VENDOR_DEMAND_FORECAST_REPORT'
     GET_PROMOTION_PERFORMANCE_REPORT = 'GET_PROMOTION_PERFORMANCE_REPORT'
     GET_BRAND_ANALYTICS_MARKET_BASKET_REPORT = 'GET_BRAND_ANALYTICS_MARKET_BASKET_REPORT'
@@ -103,3 +108,7 @@ class ReportType(str, Enum):
     GET_BRAND_ANALYTICS_ITEM_COMPARISON_REPORT = 'GET_BRAND_ANALYTICS_ITEM_COMPARISON_REPORT'
     GET_VENDOR_NET_PURE_PRODUCT_MARGIN_REPORT = 'GET_VENDOR_NET_PURE_PRODUCT_MARGIN_REPORT'
     GET_MERCHANTS_LISTINGS_FYP_REPORT = 'GET_MERCHANTS_LISTINGS_FYP_REPORT'
+    GET_FBA_SNS_FORECAST_DATA = "GET_FBA_SNS_FORECAST_DATA"
+    GET_FBA_SNS_PERFORMANCE_DATA = "GET_FBA_SNS_PERFORMANCE_DATA"
+    GET_COUPON_PERFORMANCE_REPORT = "GET_COUPON_PERFORMANCE_REPORT"
+
